==> libreoffice_7.0.4.orig.tar.xz: libreoffice-7.0.4.2/sd/source/ui/framework/module/DrawModule.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <framework/DrawModule.hxx>

#include <framework/FrameworkHelper.hxx>
#include "CenterViewFocusModule.hxx"
#include "SlideSorterModule.hxx"
#include "ToolBarModule.hxx"

using namespace ::com::sun::star;
using namespace ::com::sun::star::uno;

namespace sd::framework {

void DrawModule::Initialize (Reference<frame::XController> const & rxController)
{
    new sd::framework::CenterViewFocusModule(rxController);
    new sd::framework::SlideSorterModule(
        rxController,
        FrameworkHelper::msLeftDrawPaneURL);
    new ToolBarModule(rxController);
}

} // end of namespace sd::framework

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_7.3.2.orig.tar.xz: libreoffice-7.3.2.2/sd/source/ui/framework/module/DrawModule.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <framework/DrawModule.hxx>

#include <framework/FrameworkHelper.hxx>
#include "CenterViewFocusModule.hxx"
#include "SlideSorterModule.hxx"
#include "ToolBarModule.hxx"

using namespace ::com::sun::star;
using namespace ::com::sun::star::uno;

namespace sd::framework
{
void DrawModule::Initialize(Reference<frame::XController> const& rxController)
{
    new sd::framework::CenterViewFocusModule(rxController);
    new sd::framework::SlideSorterModule(rxController, FrameworkHelper::msLeftDrawPaneURL);
    new ToolBarModule(rxController);
}

} // end of namespace sd::framework

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
